@@ -41,8 +41,9 @@ class DefaultCommand(common.DefaultCommand):
     """
 
     def __get_cli_object(self, args):
+        api_version = self.config.server.api_version.value
         cli = AdminCli(args.host, args.user, args.password, args.verbose,
-                       args.debug)
+                      args.debug, api_version=api_version)
         if args.base_url:
             cli.base_url = args.base_url
         return cli
@@ -59,18 +60,6 @@ class DefaultCommand(common.DefaultCommand):
             self.log.error(ex.args[1] + " : " + err_suffix)
         return False
 
-    def _delete(self, method, message_ok, err_suffix, *args):
-        try:
-            if method(*args):
-                self.log.info(message_ok)
-                return True
-            else:
-                return False
-        except LinShareException as ex:
-            self.log.debug("LinShareException : " + str(ex.args))
-            self.log.error(ex.args[1] + " : " + err_suffix)
-        return False
-
 
 # -----------------------------------------------------------------------------
 class NotYetImplementedCommand(argtoolbox.DefaultCommand):
