@@ -42,7 +42,7 @@ class ThreadMembersListCommand(DefaultCommand):
     def __call__(self, args):
         super(ThreadMembersListCommand, self).__call__(args)
         cli = self.ls.thread_members
-        table = self.get_table(args, cli, self.IDENTIFIER)
+        table = self.get_table(args, cli, self.IDENTIFIER, args.fields)
         table.show_table(
             cli.list(args.uuid)
         )
@@ -54,9 +54,15 @@ class ThreadMembersListCommand(DefaultCommand):
         return (v.get('uuid')
                 for v in json_obj if v.get('uuid').startswith(prefix))
 
+    def complete_fields(self, args, prefix):
+        super(ThreadMembersListCommand, self).__call__(args)
+        cli = self.ls.thread_members
+        return cli.get_rbu().get_keys(True)
+
+
 
 # -----------------------------------------------------------------------------
-def add_parser(subparsers, name, desc):
+def add_parser(subparsers, name, desc, config):
     """Add all thread member sub commands."""
     parser_tmp = subparsers.add_parser(name, help=desc)
 
@@ -79,4 +85,4 @@ def add_parser(subparsers, name, desc):
     parser_tmp2.add_argument('--csv', action="store_true", help="Csv output")
     parser_tmp2.add_argument('--raw', action="store_true",
                              help="Disable all formatters")
-    parser_tmp2.set_defaults(__func__=ThreadMembersListCommand())
+    parser_tmp2.set_defaults(__func__=ThreadMembersListCommand(config))
