@@ -39,7 +39,9 @@ class UsersListCommand(DefaultCommand):
     def __call__(self, args):
         super(UsersListCommand, self).__call__(args)
         cli = self.ls.users
-        table = self.get_table(args, cli, self.IDENTIFIER)
+        if not  (args.firstname or args.lastname or args.mail):
+            raise ValueError('You should use at leat one option among : --firstname, --lastname or --mail')
+        table = self.get_table(args, cli, self.IDENTIFIER, args.fields)
         table.show_table(
             cli.search(args.firstname, args.lastname, args.mail),
             formatters=[DateFormatter('creationDate'),
@@ -48,17 +50,20 @@ class UsersListCommand(DefaultCommand):
         )
         return True
 
+    def complete_fields(self, args, prefix):
+        super(UsersListCommand, self).__call__(args)
+        cli = self.ls.users
+        return cli.get_rbu().get_keys(True)
+
 
 # -----------------------------------------------------------------------------
-def add_parser(subparsers, name, desc):
+def add_parser(subparsers, name, desc, config):
     """Add all user sub commands."""
     parser_tmp = subparsers.add_parser(name, help=desc)
 
     subparsers2 = parser_tmp.add_subparsers()
     parser_tmp2 = subparsers2.add_parser('list',
                                          help="list users from linshare")
-    parser_tmp2.add_argument('pattern', nargs="*",
-                             help="").completer = Completer()
     parser_tmp2.add_argument('-f', '--firstname', action="store")
     parser_tmp2.add_argument('-l', '--lastname', action="store")
     parser_tmp2.add_argument('-m', '--mail', action="store")
@@ -71,4 +76,6 @@ def add_parser(subparsers, name, desc):
     parser_tmp2.add_argument('--csv', action="store_true", help="Csv output")
     parser_tmp2.add_argument('--raw', action="store_true",
                              help="Disable all formatters")
-    parser_tmp2.set_defaults(__func__=UsersListCommand())
+    parser_tmp2.add_argument('-k', '--field', action='append', dest="fields"
+        ).completer = Completer("complete_fields")
+    parser_tmp2.set_defaults(__func__=UsersListCommand(config))
