@@ -31,15 +31,22 @@ from linshareapi.user import UserCli
 import argtoolbox
 
 
+# pylint: disable=C0111
+# Missing docstring
 # -----------------------------------------------------------------------------
 class DefaultCommand(common.DefaultCommand):
     """ Default command object use by the ser API. If you want to add a new
     command to the command line interface, your class should extend this one.
     """
 
+    IDENTIFIER = "name"
+    DEFAULT_SORT_NAME = "name"
+    RESOURCE_IDENTIFIER = "uuid"
+
     def __get_cli_object(self, args):
+        api_version = self.config.server.api_version.value
         cli = UserCli(args.host, args.user, args.password, args.verbose,
-                        args.debug)
+                      args.debug, api_version=api_version)
         if args.base_url:
             cli.base_url = args.base_url
         return cli
@@ -85,11 +92,10 @@ class ListConfigCommand(DefaultCommand):
                 print " - " + "-".join(i.split('-')[1:])
         print ""
 
-
 # -----------------------------------------------------------------------------
 def add_parser(subparsers, config):
-    parser_tmp = subparsers.add_parser('test', add_help=False)
-    parser_tmp.add_argument('files', nargs='*')
-    parser_tmp.set_defaults(__func__=TestCommand(config))
-    parser_tmp = subparsers.add_parser('list')
-    parser_tmp.set_defaults(__func__=ListConfigCommand(config))
+    parser = subparsers.add_parser('test', add_help=False)
+    parser.add_argument('files', nargs='*')
+    parser.set_defaults(__func__=TestCommand(config))
+    parser = subparsers.add_parser('list')
+    parser.set_defaults(__func__=ListConfigCommand(config))
